@@ -557,8 +557,6 @@ def ecdsa_sign(msg, priv):
 
 def ecdsa_raw_verify(msghash, vrs, pub):
     v, r, s = vrs
-    if v < 27 or v > 28:
-        return False
 
     w = inv(s, N)
     z = hash_to_int(msghash)
@@ -575,8 +573,6 @@ def ecdsa_verify(msg, sig, pub):
 
 def ecdsa_raw_recover(msghash, vrs):
     v, r, s = vrs
-    if v < 27 or v > 28:
-        return False
 
     x = r
     beta = pow(x*x*x+A*x+B, (P+1)/4, P)
